pub enum DataSource {
Show 15 variants
OfficialWebsite(OfficialWebsiteDataSource),
WikipediaPage(WikipediaPageDataSource),
LegalFramework(LegalFrameworkDataSource),
FragDenStaat(FragDenStaatDataSource),
GemdatFolders(GemdatFoldersDataSource),
GszAccordionCards(GszAccordionCardsDataSource),
CitiesApp(CitiesAppDataSource),
SessionNet(SessionNetDataSource),
CityVienna(CityViennaDataSource),
CityWels(CityWelsDataSource),
DistrictVienna(DistrictViennaDataSource),
MunicipalityBreitenfurt(MunicipalityBreitenfurtDataSource),
CityLinz(CityLinzDataSource),
CityLeonding(CityLeondingDataSource),
UnknownPageFormat(UnknownPageFormatDataSource),
}Expand description
An enumeration type representing one of the available data source descriptions.
Variants
OfficialWebsite(OfficialWebsiteDataSource)
Official website data source.
WikipediaPage(WikipediaPageDataSource)
Wikipedia page data source.
LegalFramework(LegalFrameworkDataSource)
Legal framework data source.
FragDenStaat(FragDenStaatDataSource)
Frag den Staat data source.
GemdatFolders(GemdatFoldersDataSource)
Gemdat folders data source.
GszAccordionCards(GszAccordionCardsDataSource)
GSZ accordion data source.
CitiesApp(CitiesAppDataSource)
CitiesApp data source.
SessionNet(SessionNetDataSource)
SessionNet data source.
CityVienna(CityViennaDataSource)
City Vienna data source.
CityWels(CityWelsDataSource)
City Wels data source.
DistrictVienna(DistrictViennaDataSource)
Viennese district data source.
MunicipalityBreitenfurt(MunicipalityBreitenfurtDataSource)
Municipality of Breitenfurt data source.
CityLinz(CityLinzDataSource)
City Linz data source.
CityLeonding(CityLeondingDataSource)
City Leonding data source.
UnknownPageFormat(UnknownPageFormatDataSource)
Data source for a web page in an unknown format.