pub enum DocumentKind {
MunicipalCouncilMeetingProtocol,
MunicipalCouncilMeetingInvitation,
MunicipalCouncilSummaryReport,
OfficialMunicipalJournal,
}Expand description
The kinds of documents that can be downloaded from available data sources.
Variants
MunicipalCouncilMeetingProtocol
A document containing the protocol of the municipal council meeting procedure in detail as demanded by law
A proper protocol typically follows this structure (not necessarily in exactly this order):
- A header with location and date
- A list of the present and invited but absent participants
- An agenda listing all the items planned for this session
- A detailed section describing the discussion of each agenda item in detail
- Ballot results for agenda items that require a vote
MunicipalCouncilMeetingInvitation
One or more invitations to municipal council meetings
MunicipalCouncilSummaryReport
A report or summary of the municipal council meeting summarizing the outcome of each of the agenda items
OfficialMunicipalJournal
An official journal published by a municipality.
Municipal journals frequently contain a report or summary of the most recent municipal council meeting.