pub struct DistrictViennaDataSource {
pub url: Url,
pub contained_documents: BTreeMap<DocumentKind, BTreeMap<String, String>>,
}Expand description
The data source provided by the districts of Vienna.
Fields
url: UrlThe entry url for the data source.
contained_documents: BTreeMap<DocumentKind, BTreeMap<String, String>>The kinds of documents provided by the data source.