pub struct PibInfo {
pub name: String,
pub kind: AdministrativeUnitKind,
pub data_sources: Option<Vec<DataSource>>,
pub note: Option<String>,
pub identifiers: Identifiers,
}Expand description
The information of an administrative unit stored in a file to be read by pibtool.
Fields
name: StringThe name of the administrative unit.
kind: AdministrativeUnitKindThe kind of administrative unit.
data_sources: Option<Vec<DataSource>>A list of known data sources for the administrative unit.
note: Option<String>Extra notes, if required.
identifiers: IdentifiersA set of known identifiers for the administrative unit.