pub struct SessionNetDataSource {
pub url: Url,
pub municipal_council_name: String,
pub contained_documents: BTreeMap<DocumentKind, SessionNetDocumentsConfiguration>,
}Expand description
The SessionNet data source.
Fields
url: UrlThe entry url for the data source.
municipal_council_name: StringThe name of the municipal council as declared in the SessionNet system.
contained_documents: BTreeMap<DocumentKind, SessionNetDocumentsConfiguration>The kinds of documents provided by the data source.