pub struct UnknownPageFormatDataSource {
pub url: Url,
pub contained_documents: BTreeMap<DocumentKind, BTreeMap<String, String>>,
}Expand description
The data source to be used as a placeholder for pages of which the format is not yet supported.
Fields
url: UrlThe entry url for the data source.
contained_documents: BTreeMap<DocumentKind, BTreeMap<String, String>>The kinds of documents provided by the data source.