pub trait DataSourceInfo {
// Required methods
fn is_download_supported(&self) -> bool;
fn provides_documents(&self, document_kind: DocumentKind) -> bool;
}Expand description
A trait for providing information about a data source.
Required Methods
Sourcefn is_download_supported(&self) -> bool
fn is_download_supported(&self) -> bool
Tell whether the download is supported from that data source.
Sourcefn provides_documents(&self, document_kind: DocumentKind) -> bool
fn provides_documents(&self, document_kind: DocumentKind) -> bool
Get the list of documents provided by that data source.