DataSourceInfo

Trait DataSourceInfo 

pub trait DataSourceInfo {
    // Required methods
    fn is_download_supported(&self) -> bool;
    fn provides_documents(&self, document_kind: DocumentKind) -> bool;
}
A trait for providing information about a data source.

Required Methods

fn is_download_supported(&self) -> bool

Tell whether the download is supported from that data source.

fn provides_documents(&self, document_kind: DocumentKind) -> bool

Get the list of documents provided by that data source.

Implementors